*this go to README when ready*

The Functional Ear Training method consists in educating the ear to listen to musical tones.

The method is the following:

**First**, we will begin with a given key and then play a cadence to establish
the key to the ears.

For example, the cadence of `I-IV-V-I` in the key of `C major`:

```
C - F - G - C
```

**Second**, we will play a random note inside that given key, without informing it. The student will have to guess till he learns by listening. This method makes the students do quick progress in learning to listen to the musical intervals.

**Third**, the student will be taught to:

1. Resolve the given note to the tonic below (unison) if the note is in the range from the unison to the fourth degree.

2. Resolve the given note to the tonic above if the note is in the range from the fifth degree (dominant) to the octave.

3. Currently, the `Tritone` (+4, -5) is being resolved to the greater octave. This behavior can change in 
a near future, probably wih an option to choose. where it should be solved.

So, in the key of `C minor`:

```
                     |
   I   II  III   IV  |  V   VI  VII VIII
   C    D    E    F  |  G    A    B    C
     <-------------  |  ------------>
```

`C(I)` to `F` will revolve in `C(I)`  
`G` to `C(VIII)` will resolve to `C(VIII)`
